@@ -32,7 +32,7 @@ from fresco.util.urls import url_join
 from fresco.util.http import parse_header
 from fresco.util.wsgi import unicode_to_environ
 
-__version__ = '7.4.6'
+__version__ = '7.4.7'
 
 #: Registry for xpath multimethods
 xpath_registry = {}
@@ -1721,7 +1721,7 @@ class PassStateWSGIApp(object):
         path = quote(path)
         start_response('302 Found', [('Content-Type', 'text/html'),
                                      ('Location', path)])
-        return [u'<a href="{0}">{0}</a>'.format(path).encode('utf8')]
+        return ['<a href="{0}">{0}</a>'.format(path).encode('utf8')]
 
     def first_request(self, environ, start_response):
         self.first_request_served = True
